@@ -470,7 +470,7 @@ void Titraqform::setupMenubar(void)
     nMenuid = pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
     pHelppopup->setItemEnabled(nMenuid, false);
     pHelppopup->insertSeparator();
-    pHelppopup->insertItem(trUtf8("About &Titraq"), this, SLOT(aboutTitraq()));
+    pHelppopup->insertItem(trUtf8("About &AS-GUI"), this, SLOT(aboutTitraq()));
     pHelppopup->insertItem(trUtf8("About &OSSP"), this, SLOT(aboutOSSP()));
     pHelppopup->insertItem(trUtf8("About &Qt"), this, SLOT(aboutQt()));
     pHelppopup->insertSeparator();
@@ -626,6 +626,7 @@ void Titraqform::setupTable(void)
 
     // Table update signals
     connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(updEdit(int, int)));
+    connect(m_pMaintable, SIGNAL(clicked(int, int, int, const QPoint&)), this, SLOT(onClick(int, int, int, const QPoint&)));
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
     connect(m_pMaintable, SIGNAL(textEdited(int, int)), this, SLOT(dataChanged(int, int)));
@@ -753,7 +754,7 @@ void Titraqform::setupEditlay(void)
     // Configure attributes
     m_pDateedit->setOrder(QDateEdit::YMD);
     m_pDateedit->setAutoAdvance(true);
-    m_pDateedit->setSeparator(trUtf8("."));
+    m_pDateedit->setSeparator(trUtf8("-"));
     m_pDateedit->setEnabled(false);
 
     // Whatsthis info for the date editor
@@ -963,10 +964,12 @@ void Titraqform::setupColumns(void)
 void Titraqform::enableIface(bool bTurned)
 {
     // FIXME: Does not belong here, so relocate
-    if (!bTurned)                       // Turn off the interface
-        m_pMaintable->setNumRows(0);    // Remove table data
-    else                                // Turn on the interface
+    if (bTurned)                       // Turn off the interface
         m_pDateedit->setDayfocus();     // Default focus is on day
+    else {                              // Turn on the interface
+        m_pMaintable->setNumRows(0);    // Remove table data
+        m_pStatusedit->setPixmap(QPixmap(s_kpcStatvoid_xpm));
+    }
 
     // Enable or disable the widgets
     m_pMaintable->setEnabled(bTurned);
@@ -1000,7 +1003,6 @@ void Titraqform::enableIface(bool bTurned)
 #endif // HAVE_ESOAP
 
     // Unconditional settings
-    this->updEdit(m_pMaintable->currentRow());      // Update edit controls
     m_pMaintable->setDirty(false);                  // Reset to clean data
 }
 
