@@ -62,6 +62,76 @@
 // Intentional no operation
 #define TITRAQ_NOP ((void)0)
 
+#ifdef HAVE_CONFIG_H
+#if (SIZEOF_CHAR == 1)
+typedef unsigned char        U8;
+#else
+?==Error: Undefined 8 bit type
+#endif // U8
+
+#if (SIZEOF_SHORT == 2)
+typedef unsigned short       U16;
+#elif (SIZEOF_INT == 2)
+typedef unsigned int         U16;
+#elif (SIZEOF_LONG == 2)
+typedef unsigned long        U16;
+#else
+?==Error: Undefined 16 bit type
+#endif // U16
+
+#if (SIZEOF_SHORT == 4)
+typedef unsigned short       U32;
+#elif (SIZEOF_INT == 4)
+typedef unsigned int         U32;
+#elif (SIZEOF_LONG == 4)
+typedef unsigned long        U32;
+#else
+?==Error: Undefined 32 bit type
+#endif // U32
+
+#if (SIZEOF_SHORT == 8)
+typedef unsigned short       U64;
+#elif (SIZEOF_INT == 8)
+typedef unsigned int         U64;
+#elif (SIZEOF_LONG == 8)
+typedef unsigned long        U64;
+#elif (SIZEOF_LONG_LONG == 8)
+typedef unsigned long long   U64;
+#else
+?==Error: Undefined 64 bit type
+#endif // U64
+
+#else // HAVE_CONFIG_H (not defined)
+typedef unsigned char        U8;
+#if (4 == 8)
+typedef unsigned int         U64;
+#elif (4 == 8)
+typedef unsigned long        U64;
+#elif (8 == 8)
+typedef unsigned long long   U64;
+#else
+?==Error: Undefined 64 bit type
+#endif
+
+#if (4 == 2)
+typedef	unsigned int         U16;
+#elif (2 == 2)
+typedef	unsigned short       U16;
+#else
+?==Error: Undefined 16 bit type
+#endif
+
+#if (4 == 4)
+typedef	unsigned int         U32;
+#elif (4 == 4)
+typedef	unsigned long        U32;
+#elif (2 == 4)
+typedef	unsigned short       U32;
+#else
+?== Error: Undefined 32 bit type
+#endif
+#endif // HAVE_CONFIG_H
+
 
 // Main table size
 const int g_knBlocks = 32;
@@ -170,6 +240,7 @@ protected slots:
     void aboutOSSP(void);               // Learn more about the OSSP
     void aboutQt(void);                 // Learn more about Qt
     void selAll(void);                  // Edit menu select all
+    void onClick(int, int, int, const QPoint &); // Table was clicked
     void inplaceEdit(int, int, int, const QPoint &); // Enter in place edit mode
     void updEdit(int, int nCol = 0);    // Update edit controls
     void validateData(void);            // Validate current row of matrix data
